PathSupplier
diff --git a/solr/solrj/src/java/org/apache/solr/cluster/api/PathSupplier.java b/solr/solrj/src/java/org/apache/solr/cluster/api/PathSupplier.java
index 291febe..f346dd8 100644
--- a/solr/solrj/src/java/org/apache/solr/cluster/api/PathSupplier.java
+++ b/solr/solrj/src/java/org/apache/solr/cluster/api/PathSupplier.java
@@ -16,11 +16,13 @@
  */
 package org.apache.solr.cluster.api;
 
-/**For a given route, we may have multiple url prefix.
+import java.util.Iterator;
+
+/**For a given route, we may have multiple url paths.
  * This implementation would give one after the other. If one fails, try next
  *
  */
 public interface PathSupplier {
 
-    String nextPath(ApiType apiType);
+    Iterator<String> getPaths(ApiType apiType);
 }